@@ -1,12 +1,12 @@
-from typing import Any, Dict
+from typing import Any, Dict, List
 from nonebot import get_driver, on_command, on_notice
-from nonebot.adapters.cqhttp import Bot, Event, MessageEvent, GroupMessageEvent, GroupRecallNoticeEvent
+from nonebot.adapters.onebot.v11 import Bot, Event, MessageEvent, GroupMessageEvent, GroupRecallNoticeEvent
 from nonebot.rule import to_me
-from nonebot.typing import T_State, T_CalledAPIHook
+from nonebot.typing import T_CalledAPIHook
 
 from .config import Config
-global_config = get_driver().config
-withdraw_config = Config(**global_config.dict())
+
+withdraw_config = Config.parse_obj(get_driver().config.dict())
 
 
 __help__plugin_name__ = 'withdraw'
@@ -19,7 +19,7 @@ __short_cmd__ = '@我 撤回、回复消息“撤回”'
 __usage__ = f'{__des__}\nUsage:\n{__cmd__}'
 
 
-msg_ids = {}
+msg_ids: Dict[str, List[str]] = {}
 max_size = withdraw_config.withdraw_max_size
 
 
@@ -55,11 +55,12 @@ async def save_msg_id(bot: Bot, e: Exception, api: str, data: Dict[str, Any], re
 Bot._called_api_hook.add(save_msg_id)
 
 
-withdraw = on_command('withdraw', aliases={'撤回'}, rule=to_me(), priority=10)
+withdraw = on_command('withdraw', aliases={'撤回'},
+                      block=True, rule=to_me(), priority=10)
 
 
 @withdraw.handle()
-async def _(bot: Bot, event: MessageEvent, state: T_State):
+async def _(bot: Bot, event: MessageEvent):
     if isinstance(event, GroupMessageEvent):
         msg_type = 'group'
         id = event.group_id
@@ -90,7 +91,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
         await withdraw.finish('撤回失败，可能已超时')
 
 
-async def _group_recall(bot: Bot, event: Event, state: T_State) -> bool:
+async def _group_recall(bot: Bot, event: Event) -> bool:
     if isinstance(event, GroupRecallNoticeEvent) and str(event.user_id) == str(bot.self_id):
         return True
     return False
@@ -100,7 +101,7 @@ withdraw_notice = on_notice(_group_recall, priority=10)
 
 
 @withdraw_notice.handle()
-async def _(bot: Bot, event: GroupRecallNoticeEvent, state: T_State):
+async def _(event: GroupRecallNoticeEvent):
     msg_id = int(event.message_id)
     id = event.group_id
     key = get_key('group', id)
